#
# spec file for package mirror
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mirror
Version:        2.9
Release:        912.5
Summary:        Perl Scripts for Mirroring FTP Servers
License:        SUSE-mirror
Group:          Productivity/Networking/Web/Utilities
URL:            ftp://ftp.sai.msu.su/pub/unix/FTP/mirror/
Source0:        ftp://ftp.sai.msu.su/pub/unix/FTP/mirror/%{name}-%{version}.tar.gz
Patch0:         %{name}-%{version}.patch
Patch1:         %{name}-%{version}.ftp-ls-timeout.patch
Patch2:         %{name}-%{version}.y2k-fix.patch
Patch3:         %{name}-%{version}.name_map-default.patch
Patch4:         %{name}-%{version}.gzip.patch
Patch5:         mirror-exec-path.dif
Patch6:         dont-build-as-root.diff
Patch7:         mirror-timelocal.patch
Patch8:         mirror-dump.patch
Patch9:         mirror-fix-perl-5.38-package-separator.patch
Requires:       perl = %{perl_version}
BuildArch:      noarch

%description
Mirror is a package written in Perl that uses the FTP protocol to duplicate
a directory hierarchy between the machine it is run on and a remote host. It
avoids copying files unnecessarily by comparing the file time-stamps and
file sizes before transferring. Amongst other things, it can optionally
rename, compress, gzip, and split files.

%prep
%setup -q -c
%autopatch -p1

%build

%install
install -d -m 755 %{buildroot}%{perl_vendorlib}
install -d -m 755 %{buildroot}%{_bindir}
install -d -m 755 %{buildroot}%{_mandir}/man1
%make_install PLDIR=%{perl_vendorlib}
cd %{buildroot}%{_bindir}/
ln -sf mirror-master mm

%files
%license copyright.html
%doc *.txt *.html mirror-on-dusk.gif mirror.defaults
%{perl_vendorlib}/*
%{_bindir}/*
%{_mandir}/man1/*

%changelog
* Sun Dec 10 2023 Walter Haidinger <obs-walter@haidinger.xyz>
- Fix perl 5.38+ package separator warning (bnc#1214412)
  * Added patch mirror-fix-perl-5.38-package-separator.patch
* Wed Sep  6 2023 David Anes <david.anes@suse.com>
- Refresh patches and simplify spec file a bit
* Wed Jun 27 2018 tchvatal@suse.com
- Make sure to install license using %%license macro
* Wed Jun 27 2018 zawel1@gmail.com
- minor patch to remove warning: dump -> CORE::dump
  * mirror-dump.patch
* Tue Jan 31 2017 tchvatal@suse.com
- Cleanup with spec-cleaner, use sane description bsc#1022798
- Refresh patches to use unified diff:
  * dont-build-as-root.diff
  * mirror-2.9.gzip.patch
  * mirror-2.9.name_map-default.patch
  * mirror-2.9.patch
  * mirror-2.9.y2k-fix.patch
  * mirror-exec-path.dif
  * mirror-timelocal.patch
  * mirror-2.9.ftp-ls-timeout.patch
* Wed Mar 27 2013 zawel1@gmail.com
- mirror-timelocal.patch: timelocal.pl was long obsolete and was removed
  in recent perl, it was substituted with simple call to Time::Local
  (bnc#811955)
* Wed May  9 2012 cfarrell@suse.com
- license update: SUSE-mirror
  See the explanation added in the spreadsheet linked at
  license.opensuse.org (SUSE-mirror is a new addition to that spreadsheet)
* Mon Dec  4 2006 dmueller@suse.de
- don't build as root
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Aug 20 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 28 2003 ro@suse.de
- install perl stuff to vendor location
* Fri Jul 19 2002 poeml@suse.de
- mirror-master: 'exec ./mirror' -> 'exec mirror'
* Fri Mar 15 2002 ro@suse.de
- switch default from compress to gzip
- remove requires to compress
* Tue Jul 31 2001 adostal@suse.cz
- convert gz to bz2 and dif to patch
* Wed May  9 2001 draht@suse.de
- s/unallowed/illegal/
  Language problem fixed in mirror-2.9.dif
* Mon Mar 12 2001 draht@suse.de
- added y2k fix provided by Andreas Schwab against dateconv.pl,
  mirror-2.9.y2k-fix.dif
- added fix against timeouts in directory listings
  mirror-2.9.ftp-ls-timeout.dif
- added change against ".." in pathnames provided from remote,
  mirror-2.9.name_map-default.dif (against mirror.defaults).
* Thu Nov  9 2000 cihlar@suse.cz
- clean up spec file
- fixed file list
* Fri Jul 21 2000 cihlar@suse.cz
- added more documentation
* Wed May 17 2000 cihlar@suse.cz
- Group sorted
* Wed Apr  5 2000 cihlar@suse.cz
- added BuildRoot
- clean up spec file
* Thu Jan 20 2000 ro@suse.de
- manpages to /usr/share/man
* Mon Dec  6 1999 ro@suse.de
- update to 2.9
- config-file "mirror.defaults" resides in perl_sitelib now
- re-added security patch
- added requires compress
* Sun Nov  7 1999 ro@suse.de
- removed ~ from deny-list
* Thu Sep 30 1999 bs@suse.de
- applied security fix for german umlauts etc.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Oct 22 1998 bs@suse.de
- added package name to mail subject.
* Fri Oct 16 1998 bs@suse.de
- added ftp.pl lchat.pl lsparse.pl with some fixes to get passive ftp working.
* Tue May 27 1997 florian@suse.de
- new version 2.8.f4
- include chat2.pl, as perl5.004 does not
* Tue Mar 18 1997 bs@suse.de
- echo how many files to get even if debug is disabled.
* Thu Jan  2 1997 bs@suse.de
- printing how many files are left.
- 'timezone-confusion-patch' by emoenke@gwdg.de
* Thu Jan  2 1997 florian@suse.de
- added some known bug-fixes to mirror
- made it work with perl5.003
